@@ -13,11 +13,11 @@ from gaphor.diagram.diagramtoolbox import ToolboxDefinition
 class C4ModelLanguage(ModelingLanguage):
     @property
     def name(self) -> str:
-        return gettext("C4 model")
+        return gettext("C4 Model")
 
     @property
     def toolbox_definition(self) -> ToolboxDefinition:
-        return c4model_toolbox_actions  # type: ignore[no-any-return]
+        return c4model_toolbox_actions
 
     def lookup_element(self, name):
         element_type = getattr(c4model, name, None)
