@@ -4,7 +4,7 @@ from gaphas.item import SE
 
 from gaphor.core import gettext
 from gaphor.diagram.diagramtoolbox import ToolDef, ToolSection, namespace_config
-from gaphor.diagram.diagramtools import new_item_factory
+from gaphor.diagram.tools import new_item_factory
 from gaphor.SysML import diagramitems as sysml_items
 from gaphor.SysML import sysml
 from gaphor.UML.classes import ContainmentItem
@@ -33,7 +33,7 @@ requirements = ToolSection(
         ),
         ToolDef(
             "toolbox-derive-reqt-dependency",
-            gettext("Derive Reqt"),
+            gettext("Derive Requirement"),
             "gaphor-derive-symbolic",
             "<Shift>D",
             new_item_factory(sysml_items.DeriveReqtItem),
