@@ -5,10 +5,18 @@ from gaphor.core.modeling.properties import attribute
 from gaphor.diagram.presentation import ElementPresentation, Named
 from gaphor.diagram.shapes import Box, IconBox, Text, draw_border
 from gaphor.diagram.support import represents
+from gaphor.i18n import gettext
 from gaphor.UML.modelfactory import stereotypes_str
 
 DEFAULT_UPPER_BOUND = "*"
 
+ORDERING_TEXT = {
+    "unordered": gettext("unordered"),
+    "ordered": gettext("ordered"),
+    "LIFO": gettext("LIFO"),
+    "FIFO": gettext("FIFO"),
+}
+
 
 @represents(UML.ObjectNode)
 class ObjectNodeItem(ElementPresentation, Named):
@@ -36,13 +44,17 @@ class ObjectNodeItem(ElementPresentation, Named):
                 Text(
                     text=lambda: self.subject.upperBound
                     not in (None, "", DEFAULT_UPPER_BOUND)
-                    and f"{{ upperBound = {self.subject.upperBound} }}"
+                    and "{{ {} = {} }}".format(
+                        gettext("upperBound"), self.subject.upperBound
+                    )
                     or "",
                 ),
                 Text(
                     text=lambda: self.show_ordering
                     and self.subject.ordering
-                    and f"{{ ordering = {self.subject.ordering} }}"
+                    and "{{ {} = {} }}".format(
+                        gettext("ordering"), ORDERING_TEXT.get(self.subject.ordering)
+                    )
                     or "",
                 ),
             ),
