@@ -2,6 +2,9 @@ from gaphor.UML.classes import (
     classconnect,
     classeseditors,
     classespropertypages,
+    associationpropertypages,
+    dependencypropertypages,
+    enumerationpropertypages,
     containmentconnect,
     copypaste,
     interfaceconnect,
