@@ -1,26 +1,15 @@
 from gaphas.geometry import Rectangle, distance_point_point_fast
 
-from gaphor.core import transactional
 from gaphor.core.format import format, parse
 from gaphor.diagram.inlineeditors import InlineEditor, popup_entry, show_popover
+from gaphor.transaction import Transaction
 from gaphor.UML.classes.association import AssociationItem
 
 
 @InlineEditor.register(AssociationItem)
-def association_item_inline_editor(item, view, pos=None) -> bool:
+def association_item_inline_editor(item, view, event_manager, pos=None) -> bool:
     """Text edit support for Named items."""
 
-    @transactional
-    def update_text(text):
-        item.subject.name = text
-        return True
-
-    @transactional
-    def update_end_text(text):
-        assert end_item
-        parse(end_item.subject, text)
-        return True
-
     subject = item.subject
     if not subject:
         return False
@@ -44,21 +33,24 @@ def association_item_inline_editor(item, view, pos=None) -> bool:
             or ""
         )
 
-        def escape():
+        entry = popup_entry(text)
+
+        def update_text():
             assert end_item
-            parse(end_item.subject, text)
+            with Transaction(event_manager):
+                parse(end_item.subject, entry.get_buffer().get_text())
 
-        entry = popup_entry(text, update_end_text)
         bb = end_item.name_bounds
         x, y = view.get_matrix_i2v(item).transform_point(bb.x, bb.y)
         box = Rectangle(x, y, 10, 10)
     else:
         text = item.subject.name or ""
 
-        def escape():
-            item.subject.name = text
+        entry = popup_entry(text)
 
-        entry = popup_entry(text, update_text)
+        def update_text():
+            with Transaction(event_manager):
+                item.subject.name = entry.get_buffer().get_text()
 
         box = item.middle_shape_size
         i2v = view.get_matrix_i2v(item)
@@ -66,5 +58,5 @@ def association_item_inline_editor(item, view, pos=None) -> bool:
         w, h = i2v.transform_distance(box.width, box.height)
         box = Rectangle(x, y, w, h)
 
-    show_popover(entry, view, box, escape)
+    show_popover(entry, view, box, update_text)
     return True
