@@ -7,7 +7,7 @@ from gaphas.item import SE
 from gaphor import UML
 from gaphor.core import gettext
 from gaphor.diagram.diagramtoolbox import ToolDef, ToolSection, namespace_config
-from gaphor.diagram.diagramtools import new_item_factory
+from gaphor.diagram.tools import new_item_factory
 from gaphor.UML import diagramitems
 
 
@@ -117,6 +117,7 @@ classes = ToolSection(
             "gaphor-dependency-symbolic",
             "<Shift>D",
             new_item_factory(diagramitems.DependencyItem),
+            handle_index=0,
         ),
         ToolDef(
             "toolbox-generalization",
@@ -124,6 +125,7 @@ classes = ToolSection(
             "gaphor-generalization-symbolic",
             "<Shift>G",
             new_item_factory(diagramitems.GeneralizationItem),
+            handle_index=0,
         ),
         ToolDef(
             "toolbox-interface-realization",
