@@ -1,10 +1,11 @@
 import itertools
 
 from gaphor.diagram.copypaste import copy, copy_named_element
-from gaphor.UML import Association, Class, Interface, Operation
+from gaphor.UML import Association, Class, DataType, Enumeration, Interface, Operation
 
 
 @copy.register(Class)
+@copy.register(DataType)
 @copy.register(Interface)
 def copy_class(element):
     yield element.id, copy_named_element(element)
@@ -16,15 +17,23 @@ def copy_class(element):
 
 
 @copy.register
-def copy_operation(element: Operation):
+def copy_enumeration(element: Enumeration):
     yield element.id, copy_named_element(element)
     for feature in itertools.chain(
-        element.formalParameter,
-        element.returnResult,
+        element.ownedAttribute,
+        element.ownedOperation,
+        element.ownedLiteral,
     ):
         yield from copy(feature)
 
 
+@copy.register
+def copy_operation(element: Operation):
+    yield element.id, copy_named_element(element)
+    for feature in element.ownedParameter:
+        yield from copy(feature)
+
+
 @copy.register
 def copy_association(element: Association):
     yield element.id, copy_named_element(element)
