@@ -2,7 +2,13 @@ from gi.repository import Gtk
 
 from gaphor import UML
 from gaphor.core import transactional
-from gaphor.diagram.propertypages import PropertyPageBase, PropertyPages, new_builder
+from gaphor.diagram.propertypages import (
+    PropertyPageBase,
+    PropertyPages,
+    new_resource_builder,
+)
+
+new_builder = new_resource_builder("gaphor.UML.profiles")
 
 
 def _issubclass(c, b):
@@ -39,7 +45,13 @@ class MetaclassPropertyPage(PropertyPageBase):
         if not UML.model.is_metaclass(self.subject):
             return
 
-        builder = new_builder("metaclass-editor")
+        builder = new_builder(
+            "metaclass-editor",
+            signals={
+                "metaclass-combo-changed": (self._on_name_changed,),
+                "metaclass-combo-destroy": (self.watcher.unsubscribe_all,),
+            },
+        )
 
         combo = builder.get_object("metaclass-combo")
         for c in self.CLASSES:
@@ -56,18 +68,11 @@ class MetaclassPropertyPage(PropertyPageBase):
         entry.set_text(self.subject and self.subject.name or "")
 
         def handler(event):
-            if event.element is self.subject and event.new_value is not None:
-                entry.set_text(event.new_value)
+            if event.element is self.subject and entry.get_text() != event.new_value:
+                entry.set_text(event.new_value or "")
 
         self.watcher.watch("name", handler)
 
-        builder.connect_signals(
-            {
-                "metaclass-combo-changed": (self._on_name_changed,),
-                "metaclass-combo-destroy": (self.watcher.unsubscribe_all,),
-            }
-        )
-
         return builder.get_object("metaclass-editor")
 
     @transactional
