@@ -11,9 +11,15 @@ from gaphor.diagram.general import CommentLineItem
 
 
 def undo_guard(func):
+    """Do not execute the sanitizer if we're undoing a transaction.
+
+    The sanitizer actions are already part of that transaction.
+    """
+
     def guard(self, event):
-        if not (self.undo_manager and self.undo_manager.in_undo_transaction()):
-            func(self, event)
+        if self.undo_manager and self.undo_manager.in_undo_transaction():
+            return
+        return func(self, event)
 
     return guard
 
