@@ -5,11 +5,15 @@ from gaphas.item import SE
 from gaphor import UML
 from gaphor.core import gettext
 from gaphor.diagram.diagramtoolbox import ToolDef, ToolSection
-from gaphor.diagram.diagramtools import new_item_factory
+from gaphor.diagram.tools import new_item_factory
 from gaphor.UML import diagramitems
 from gaphor.UML.modelfactory import owner_package
 
 
+def state_config(new_item):
+    state_machine_config(new_item, name=gettext("State"))
+
+
 def initial_pseudostate_config(new_item):
     new_item.subject.kind = "initial"
     state_machine_config(new_item)
@@ -20,9 +24,10 @@ def history_pseudostate_config(new_item):
     state_machine_config(new_item)
 
 
-def state_machine_config(new_item):
+def state_machine_config(new_item, name=None):
     subject = new_item.subject
-    subject.name = f"New{type(subject).__name__}"
+    if name:
+        subject.name = gettext("New {name}").format(name=name)
     if subject.container:
         return
 
@@ -41,14 +46,14 @@ def state_machine_config(new_item):
         state_machine = state_machines[0]
     else:
         state_machine = subject.model.create(UML.StateMachine)
-        state_machine.name = "StateMachine"
+        state_machine.name = gettext("State Machine")
         state_machine.package = package
 
     if state_machine.region:
         region = state_machine.region[0]
     else:
         region = subject.model.create(UML.Region)
-        region.name = "DefaultRegion"
+        region.name = gettext("Default Region")
         region.stateMachine = state_machine
 
     subject.container = region
@@ -63,7 +68,9 @@ states = ToolSection(
             "gaphor-state-symbolic",
             "s",
             new_item_factory(
-                diagramitems.StateItem, UML.State, config_func=state_machine_config
+                diagramitems.StateItem,
+                UML.State,
+                config_func=state_config,
             ),
             handle_index=SE,
         ),
