@@ -4,7 +4,7 @@ from gaphas.util import path_ellipse
 
 from gaphor import UML
 from gaphor.diagram.presentation import Classified, ElementPresentation
-from gaphor.diagram.shapes import Box, EditableText, Text, stroke
+from gaphor.diagram.shapes import Box, Text, stroke
 from gaphor.diagram.support import represents
 from gaphor.diagram.text import FontWeight
 from gaphor.UML.modelfactory import stereotypes_str
@@ -15,16 +15,15 @@ class UseCaseItem(ElementPresentation, Classified):
     """Presentation of gaphor.UML.UseCase."""
 
     def __init__(self, diagram, id=None):
-        super().__init__(diagram, id)
+        super().__init__(diagram, id, height=30)
         self.shape = Box(
             Text(
                 text=lambda: stereotypes_str(self.subject),
             ),
-            EditableText(
+            Text(
                 text=lambda: self.subject.name or "",
                 style={"font-weight": FontWeight.BOLD},
             ),
-            style={"min-width": 50, "min-height": 30},
             draw=draw_usecase,
         )
 
@@ -40,4 +39,4 @@ def draw_usecase(box, context, bounding_box):
 
     cr.move_to(bounding_box.width, ry)
     path_ellipse(cr, rx, ry, bounding_box.width, bounding_box.height)
-    stroke(context, highlight=True)
+    stroke(context)
