@@ -5,7 +5,7 @@ from gaphas.item import SE
 from gaphor import UML
 from gaphor.core import gettext
 from gaphor.diagram.diagramtoolbox import ToolDef, ToolSection, namespace_config
-from gaphor.diagram.diagramtools import new_item_factory
+from gaphor.diagram.tools import new_item_factory
 from gaphor.UML import diagramitems
 
 use_cases = ToolSection(
@@ -48,6 +48,7 @@ use_cases = ToolSection(
             "gaphor-include-symbolic",
             "<Shift>U",
             new_item_factory(diagramitems.IncludeItem),
+            handle_index=0,
         ),
         ToolDef(
             "toolbox-extend",
@@ -55,6 +56,7 @@ use_cases = ToolSection(
             "gaphor-extend-symbolic",
             "<Shift>X",
             new_item_factory(diagramitems.ExtendItem),
+            handle_index=0,
         ),
     ),
 )
