@@ -6,11 +6,10 @@ session is represented as a window in which a diagram can be edited.
 
 from __future__ import annotations
 
+import importlib.metadata
 import logging
 from typing import Iterator, TypeVar, cast
 
-import importlib_metadata
-
 from gaphor import transaction
 from gaphor.abc import ActionProvider, Service
 from gaphor.action import action
@@ -37,8 +36,8 @@ logger = logging.getLogger(__name__)
 
 
 def distribution():
-    """The PkgResources distribution for Gaphor."""
-    return importlib_metadata.distribution("gaphor")
+    """The distribution metadata for Gaphor."""
+    return importlib.metadata.distribution("gaphor")
 
 
 class NotInitializedError(Exception):
