@@ -8,14 +8,23 @@ import logging
 import uuid
 from dataclasses import dataclass
 from functools import lru_cache
-from typing import Iterable, Iterator, Sequence, TypeVar
+from typing import (
+    Callable,
+    Iterable,
+    Iterator,
+    Protocol,
+    Sequence,
+    TypeVar,
+    overload,
+    runtime_checkable,
+)
 
 import gaphas
-from typing_extensions import Protocol, runtime_checkable
+from cairo import Context as CairoContext
 
 from gaphor.core.modeling.collection import collection
 from gaphor.core.modeling.element import Element, Id, RepositoryProtocol
-from gaphor.core.modeling.event import AssociationDeleted
+from gaphor.core.modeling.event import AssociationAdded, AssociationDeleted
 from gaphor.core.modeling.presentation import Presentation
 from gaphor.core.modeling.properties import (
     association,
@@ -28,7 +37,6 @@ from gaphor.core.styling import Style, StyleNode
 
 log = logging.getLogger(__name__)
 
-
 # Not all styles are requires: "background-color", "font-weight",
 # "text-color", and "text-decoration" are optional (can default to None)
 FALLBACK_STYLE: Style = {
@@ -59,7 +67,7 @@ class DrawContext:
     like selected and focused.
     """
 
-    cairo: gaphas.types.CairoContext
+    cairo: CairoContext
     style: Style
     selected: bool
     focused: bool
@@ -96,11 +104,10 @@ def rgetattr(obj, names):
                 yield from rgetattr(m, tail)
         else:
             yield from v
-    else:
-        if tail:
-            yield from rgetattr(v, tail)
-        elif v is not None:
-            yield v
+    elif tail:
+        yield from rgetattr(v, tail)
+    elif v is not None:
+        yield v
 
 
 def attrstr(obj):
@@ -117,6 +124,15 @@ def attrstr(obj):
     return ""
 
 
+def qualifiedName(element: Element) -> list[str]:
+    """Returns the qualified name of the element as a tuple."""
+    name: str = getattr(element, "name", "??")
+    if element.owner:
+        return qualifiedName(element.owner) + [name]
+    else:
+        return [name]
+
+
 class StyledDiagram:
     def __init__(
         self, diagram: Diagram, selection: gaphas.view.Selection | None = None
@@ -198,6 +214,9 @@ class StyledItem:
         )
 
 
+P = TypeVar("P", bound=Presentation)
+
+
 class Diagram(Element):
     """Diagrams may contain model elements and can be owned by a Package."""
 
@@ -217,15 +236,40 @@ class Diagram(Element):
         self._registered_views: set[gaphas.view.model.View] = set()
 
         self._watcher = self.watcher()
-        self._watcher.watch("ownedPresentation", self._presentation_removed)
+        self._watcher.watch("ownedPresentation", self._owned_presentation_changed)
+        self._watcher.watch("ownedPresentation.parent", self._order_owned_presentation)
 
     ownedPresentation: relation_many[Presentation] = association(
         "ownedPresentation", Presentation, composite=True, opposite="diagram"
     )
 
-    def _presentation_removed(self, event):
+    @property
+    def qualifiedName(self) -> list[str]:
+        """Returns the qualified name of the element as a tuple."""
+        return qualifiedName(self)
+
+    def _owned_presentation_changed(self, event):
         if isinstance(event, AssociationDeleted) and event.old_value:
             self._update_views(removed_items=(event.old_value,))
+        elif isinstance(event, AssociationAdded):
+            self._order_owned_presentation()
+
+    def _order_owned_presentation(self, event=None):
+        if event and event.property is not Presentation.parent:
+            return
+
+        ownedPresentation = self.ownedPresentation
+
+        def traverse_items(parent=None) -> Iterable[Presentation]:
+            for item in ownedPresentation:
+                if item.parent is parent:
+                    yield item
+                    yield from traverse_items(item)
+
+        new_order = sorted(
+            traverse_items(), key=lambda e: int(isinstance(e, gaphas.Line))
+        )
+        self.ownedPresentation.order(new_order.index)
 
     @property
     def styleSheet(self) -> StyleSheet | None:
@@ -242,6 +286,7 @@ class Diagram(Element):
 
     def postload(self):
         """Handle post-load functionality for the diagram."""
+        self._order_owned_presentation()
         super().postload()
 
     def create(self, type, parent=None, subject=None):
@@ -279,7 +324,21 @@ class Diagram(Element):
         self._watcher.unsubscribe_all()
         super().unlink()
 
-    def select(self, expression=None) -> Iterator[Presentation]:
+    @overload
+    def select(
+        self, expression: Callable[[Presentation], bool]
+    ) -> Iterator[Presentation]:
+        ...
+
+    @overload
+    def select(self, expression: type[P]) -> Iterator[P]:
+        ...
+
+    @overload
+    def select(self, expression: None) -> Iterator[Presentation]:
+        ...
+
+    def select(self, expression=None):
         """Return a iterator of all canvas items that match expression."""
         if expression is None:
             yield from self.get_all_items()
@@ -294,16 +353,7 @@ class Diagram(Element):
 
     def get_all_items(self) -> Iterable[Presentation]:
         """Get all items owned by this diagram, ordered depth-first."""
-
-        def iter_children(item):
-            for child in item.children:
-                yield child
-                yield from iter_children(child)
-
-        for root in self.ownedPresentation:
-            if not root.parent:
-                yield root
-                yield from iter_children(root)
+        yield from self.ownedPresentation
 
     def get_parent(self, item: Presentation) -> Presentation | None:
         return item.parent
@@ -316,7 +366,8 @@ class Diagram(Element):
         return (n for n in self.get_all_items() if n in items_set)
 
     def request_update(self, item: gaphas.item.Item) -> None:
-        self._update_views(dirty_items=(item,))
+        if item in self.ownedPresentation:
+            self._update_views(dirty_items=(item,))
 
     def _update_views(self, dirty_items=(), removed_items=()):
         """Send an update notification to all registered views."""
@@ -369,9 +420,6 @@ Presentation.diagram = association(
 )
 
 
-P = TypeVar("P", bound=Presentation)
-
-
 @runtime_checkable
 class PresentationRepositoryProtocol(Protocol):
     def create_as(self, type: type[P], id: str, diagram: Diagram) -> P:
