@@ -5,10 +5,7 @@ from __future__ import annotations
 
 import logging
 import uuid
-from contextlib import contextmanager
-from typing import TYPE_CHECKING, Callable, Iterator, TypeVar, overload
-
-from typing_extensions import Protocol
+from typing import TYPE_CHECKING, Callable, Iterator, Protocol, TypeVar, overload
 
 from gaphor.core.modeling.event import ElementUpdated
 from gaphor.core.modeling.properties import (
@@ -81,7 +78,7 @@ class Element:
         return self._model
 
     @classmethod
-    def umlproperties(class_):
+    def umlproperties(class_) -> Iterator[umlproperty]:
         """Iterate over all properties."""
         umlprop = umlproperty
         for propname in dir(class_):
@@ -143,7 +140,7 @@ class Element:
         if model:
             model.handle(event)
 
-    def watcher(self, default_handler=None) -> EventWatcherProtocol:
+    def watcher(self, default_handler: Handler | None = None) -> EventWatcherProtocol:
         model = self._model
         if model:
             return model.watcher(self, default_handler)
@@ -202,10 +199,6 @@ class RepositoryProtocol(Protocol):
     def handle(self, event: object) -> None:
         ...
 
-    @contextmanager
-    def block_events(self) -> Iterator[RepositoryProtocol]:
-        ...
-
 
 class EventWatcherProtocol(Protocol):
     def watch(self, path: str, handler: Handler | None = None) -> EventWatcherProtocol:
