@@ -8,7 +8,7 @@ from typing import TYPE_CHECKING, Generic, TypeVar
 
 from gaphas.item import Matrices
 
-from gaphor.core.modeling.element import Element, UnlinkEvent
+from gaphor.core.modeling.element import Element, Id, UnlinkEvent
 from gaphor.core.modeling.event import RevertibeEvent
 from gaphor.core.modeling.properties import association, relation_many, relation_one
 
@@ -23,18 +23,12 @@ log = logging.getLogger(__name__)
 
 class Presentation(Matrices, Element, Generic[S]):
     """This presentation is used to link the behaviors of
-    `gaphor.core.modeling` and `gaphas.Item`.
+    `gaphor.core.modeling` and `gaphas.Item`."""
 
-    Note that Presentations are not managed by the Element Factory.
-    Instead, Presentation objects are owned by Diagram. As a result they
-    do not emit ElementCreated and ElementDeleted events. Presentations
-    have their own create and delete events: ElementCreated and
-    ElementDeleted.
-    """
-
-    def __init__(self, diagram: Diagram, id=None):
+    def __init__(self, diagram: Diagram, id: Id | None = None) -> None:
         super().__init__(id=id, model=diagram.model)
         self.diagram = diagram
+        self._original_diagram = diagram
 
         def update(event):
             if self.diagram:
@@ -86,9 +80,9 @@ class Presentation(Matrices, Element, Generic[S]):
 
     def unlink(self):
         """Remove the item from the diagram and set subject to None."""
-        self.inner_unlink(UnlinkEvent(self, diagram=self.diagram))
+        self.inner_unlink(UnlinkEvent(self, diagram=self._original_diagram))
 
-    def inner_unlink(self, unlink_event: UnlinkEvent):
+    def inner_unlink(self, unlink_event: UnlinkEvent) -> None:
         self._watcher.unsubscribe_all()
         self.matrix.remove_handler(self._on_matrix_changed)
 
@@ -102,11 +96,9 @@ class Presentation(Matrices, Element, Generic[S]):
         super().inner_unlink(unlink_event)
 
     def _on_diagram_changed(self, event):
-        log.debug("Diagram changed. Unlinking %s.", self)
-        diagram = event.old_value
-        if diagram:
-            self.inner_unlink(UnlinkEvent(self, diagram))
-        if event.new_value:
+        new_value = event.new_value
+        if new_value and new_value is not self._original_diagram:
+            self.diagram = self._original_diagram
             raise ValueError("Can not change diagram for a presentation")
 
     def _on_parent_changed(self, event):
