@@ -13,7 +13,7 @@ from gaphor import UML
 from gaphor.core import gettext
 from gaphor.core.modeling import Diagram, Presentation
 from gaphor.diagram import general
-from gaphor.diagram.diagramtools import new_item_factory
+from gaphor.diagram.tools import new_item_factory
 from gaphor.UML.modelfactory import owner_package
 
 ItemFactory = Callable[[Diagram, Optional[Presentation]], Presentation]
@@ -23,9 +23,11 @@ def default_namespace(new_item):
     new_item.subject.package = owner_package(new_item.diagram)
 
 
-def namespace_config(new_item):
+def namespace_config(new_item, name=None):
     default_namespace(new_item)
-    new_item.subject.name = f"New{type(new_item.subject).__name__}"
+    new_item.subject.name = gettext("New {name}").format(
+        name=name or type(new_item.subject).__name__
+    )
 
 
 class ToolDef(NamedTuple):
