@@ -2,13 +2,13 @@ from __future__ import annotations
 
 from dataclasses import replace
 from math import pi
-from typing import Callable, List, Optional, Tuple
+from typing import Callable
 
 from gaphas.geometry import Rectangle
 
 from gaphor.core.modeling import DrawContext, UpdateContext
-from gaphor.core.styling import Style, TextAlign, VerticalAlign
-from gaphor.diagram.text import Layout, focus_box_pos
+from gaphor.core.styling import Style, TextAlign, VerticalAlign, merge_styles
+from gaphor.diagram.text import Layout
 
 
 class cairo_state:
@@ -23,12 +23,7 @@ class cairo_state:
         self._cr.restore()
 
 
-def combined_style(item_style: Style, inline_style: Style = {}) -> Style:
-    """Combine context style and inline styles into one style."""
-    return {**item_style, **inline_style}  # type: ignore[misc]
-
-
-def stroke(context: DrawContext, fill=True, highlight=False):
+def stroke(context: DrawContext, fill=True, dash=True):
     style = context.style
     cr = context.cairo
     fill_color = style.get("background-color")
@@ -37,9 +32,6 @@ def stroke(context: DrawContext, fill=True, highlight=False):
             cr.set_source_rgba(*fill_color)
             cr.fill_preserve()
 
-    if highlight:
-        draw_highlight(context)
-
     with cairo_state(cr):
         stroke = style.get("color")
         if stroke:
@@ -47,6 +39,8 @@ def stroke(context: DrawContext, fill=True, highlight=False):
         line_width = style.get("line-width")
         if line_width:
             cr.set_line_width(line_width)
+        if dash:
+            cr.set_dash(style.get("dash-style", ()), 0)
         cr.stroke()
 
 
@@ -72,8 +66,6 @@ def draw_border(box, context: DrawContext, bounding_box: Rectangle):
 
     cr.close_path()
 
-    draw_highlight(context)
-
     stroke(context)
 
 
@@ -86,16 +78,6 @@ def draw_top_separator(box: Box, context: DrawContext, bounding_box: Rectangle):
     stroke(context, fill=False)
 
 
-def draw_highlight(context: DrawContext):
-    if not context.dropzone:
-        return
-    with cairo_state(context.cairo) as cr:
-        highlight_color = context.style["highlight-color"]
-        cr.set_source_rgba(*highlight_color)
-        cr.set_line_width(cr.get_line_width() + 3.8)
-        cr.stroke_preserve()
-
-
 class Box:
     """A box like shape.
 
@@ -111,10 +93,10 @@ class Box:
         self,
         *children,
         style: Style = {},
-        draw: Optional[Callable[[Box, DrawContext, Rectangle], None]] = None,
+        draw: Callable[[Box, DrawContext, Rectangle], None] | None = None,
     ):
         self.children = children
-        self.sizes: List[Tuple[int, int]] = []
+        self.sizes: list[tuple[int, int]] = []
         self._inline_style = style
         self._draw_border = draw
 
@@ -128,7 +110,7 @@ class Box:
         return self.children[index]
 
     def size(self, context: UpdateContext):
-        style: Style = combined_style(context.style, self._inline_style)
+        style = merge_styles(context.style, self._inline_style)
         min_width = style.get("min-width", 0)
         min_height = style.get("min-height", 0)
         padding_top, padding_right, padding_bottom, padding_left = style["padding"]
@@ -149,7 +131,7 @@ class Box:
             return min_width, min_height
 
     def draw(self, context: DrawContext, bounding_box: Rectangle):
-        style: Style = combined_style(context.style, self._inline_style)
+        style = merge_styles(context.style, self._inline_style)
         new_context = replace(context, style=style)
         padding_top, padding_right, padding_bottom, padding_left = style["padding"]
         valign = style.get("vertical-align", VerticalAlign.MIDDLE)
@@ -188,11 +170,11 @@ class IconBox:
     def __init__(self, icon, *children, style: Style = {}):
         self.icon = icon
         self.children = children
-        self.sizes: List[Tuple[int, int]] = []
+        self.sizes: list[tuple[int, int]] = []
         self._inline_style = style
 
     def size(self, context: UpdateContext):
-        style = combined_style(context.style, self._inline_style)
+        style = merge_styles(context.style, self._inline_style)
         min_width = style.get("min-width", 0)
         min_height = style.get("min-height", 0)
         padding_top, padding_right, padding_bottom, padding_left = style["padding"]
@@ -236,7 +218,7 @@ class IconBox:
         )
 
     def draw(self, context: DrawContext, bounding_box: Rectangle):
-        style = combined_style(context.style, self._inline_style)
+        style = merge_styles(context.style, self._inline_style)
         new_context = replace(context, style=style)
         padding_top, padding_right, padding_bottom, padding_left = style["padding"]
         x = bounding_box.x + padding_left
@@ -265,7 +247,7 @@ class Text:
             return ""
 
     def size(self, context: UpdateContext):
-        style = combined_style(context.style, self._inline_style)
+        style = merge_styles(context.style, self._inline_style)
         min_w = style.get("min-width", 0)
         min_h = style.get("min-height", 0)
         text_align = style.get("text-align", TextAlign.CENTER)
@@ -293,7 +275,7 @@ class Text:
 
     def draw(self, context: DrawContext, bounding_box: Rectangle):
         """Draw the text, return the location and size."""
-        style = combined_style(context.style, self._inline_style)
+        style = merge_styles(context.style, self._inline_style)
         min_w = max(style.get("min-width", 0), bounding_box.width)
         min_h = max(style.get("min-height", 0), bounding_box.height)
         text_box = self.text_box(style, bounding_box)
@@ -309,38 +291,6 @@ class Text:
             layout.show_layout(cr, text_box.width, default_size=(min_w, min_h))
 
 
-class EditableText(Text):
-    def __init__(self, text=lambda: "", width=lambda: -1, style: Style = {}):
-        super().__init__(text, width, {"min-width": 30, "min-height": 14, **style})  # type: ignore[misc]
-        self.focus_box = Rectangle()
-
-    @property
-    def bounding_box(self):
-        """Bounding box is used by the inline editor."""
-        return self.focus_box
-
-    def size(self, context: UpdateContext):
-        text_size = super().size(context)
-        w, h = text_size
-        self.focus_box.width = w
-        self.focus_box.height = h
-        return text_size
-
-    def draw(self, context: DrawContext, bounding_box: Rectangle):
-        """Draw the editable text."""
-        super().draw(context, bounding_box)
-        style = combined_style(context.style, self._inline_style)
-
-        text_box = self.text_box(style, bounding_box)
-        text_align = style.get("text-align", TextAlign.CENTER)
-        focus_box = self.focus_box
-        x, y = focus_box_pos(text_box, (focus_box.width, focus_box.height), text_align)
-        focus_box.x = x
-        focus_box.y = y
-
-        text_draw_focus_box(context, *focus_box)
-
-
 def draw_default_head(context: DrawContext):
     """Default head drawer: move cursor to the first handle."""
     context.cairo.move_to(0, 0)
@@ -353,29 +303,38 @@ def draw_default_tail(context: DrawContext):
 
 def draw_arrow_head(context: DrawContext):
     cr = context.cairo
+    cr.save()
     cr.set_dash((), 0)
     cr.move_to(15, -6)
     cr.line_to(0, 0)
     cr.line_to(15, 6)
+    stroke(context, dash=False)
+    cr.restore()
     cr.move_to(0, 0)
 
 
 def draw_arrow_tail(context: DrawContext):
     cr = context.cairo
     cr.line_to(0, 0)
+    cr.save()
+    cr.set_dash((), 0)
     cr.move_to(15, -6)
     cr.line_to(0, 0)
     cr.line_to(15, 6)
+    stroke(context, dash=False)
+    cr.restore()
 
 
-def text_draw_focus_box(context, x, y, w, h):
-    if context.hovered or context.focused:
-        with cairo_state(context.cairo) as cr:
-            cr.set_dash((), 0)
-            if context.focused:
-                cr.set_source_rgb(0.6, 0.6, 0.6)
-            else:
-                cr.set_source_rgb(0.8, 0.8, 0.8)
-            cr.set_line_width(0.5)
-            cr.rectangle(x, y, w, h)
-            cr.stroke()
+def draw_diamond(
+    context: DrawContext, x1: float, x2: float, y1: float, y2: float
+) -> None:
+    """Draw a diamond."""
+    cr = context.cairo
+    center_x = x1 + (x2 - x1) / 2.0
+    center_y = y1 + (y2 - y1) / 2.0
+    cr.move_to(x1, center_y)
+    cr.line_to(center_x, y2)
+    cr.line_to(x2, center_y)
+    cr.line_to(center_x, y1)
+    cr.line_to(x1, center_y)
+    stroke(context)
