@@ -3,50 +3,46 @@
 (help browser anyone?)
 """
 
-import importlib
-
-import importlib_metadata
 from gi.repository import Gtk
 
 from gaphor.abc import ActionProvider, Service
+from gaphor.application import distribution
 from gaphor.core import action
+from gaphor.i18n import translated_ui_string
 
 
 class HelpService(Service, ActionProvider):
-    def __init__(self, session):
-        self.session = session
+    def __init__(self, main_window):
+        self.main_window = main_window
 
     def shutdown(self):
         pass
 
     @property
     def window(self):
-        return self.session.get_service("main_window").window
+        return self.main_window.window
 
-    @action(name="app.about")
+    @action(name="about")
     def about(self):
         builder = Gtk.Builder()
-        with importlib.resources.path(
-            "gaphor.services.helpservice", "about.ui"
-        ) as glade_file:
-            builder.add_objects_from_file(str(glade_file), ("about",))
+        builder.add_from_string(
+            translated_ui_string("gaphor.services.helpservice", "about.ui")
+        )
 
         about = builder.get_object("about")
 
-        about.set_version(importlib_metadata.version("gaphor"))
-        about.set_modal(True)
+        about.set_version(distribution().version)
         about.set_transient_for(self.window)
 
         about.run()
         about.destroy()
 
-    @action(name="app.shortcuts")
+    @action(name="win.shortcuts")
     def shortcuts(self):
         builder = Gtk.Builder()
-        with importlib.resources.path(
-            "gaphor.services.helpservice", "shortcuts.ui"
-        ) as glade_file:
-            builder.add_objects_from_file(str(glade_file), ("shortcuts-gaphor",))
+        builder.add_from_string(
+            translated_ui_string("gaphor.services.helpservice", "shortcuts.ui")
+        )
 
         shortcuts = builder.get_object("shortcuts-gaphor")
         shortcuts.set_modal(True)
