@@ -9,12 +9,10 @@ __all__ = ["load", "save"]
 import io
 import logging
 import os.path
-import uuid
 from functools import partial
 
 from gaphor import application
 from gaphor.core.modeling.collection import collection
-from gaphor.core.modeling.diagram import Diagram, PseudoCanvas
 from gaphor.core.modeling.element import Element
 from gaphor.core.modeling.presentation import Presentation
 from gaphor.core.modeling.stylesheet import StyleSheet
@@ -137,10 +135,6 @@ def save_element(name, value, writer):
         save_reference(name, value)
     elif isinstance(value, collection):
         save_collection(name, value)
-    elif isinstance(value, PseudoCanvas):
-        writer.startElement("canvas", {})
-        value.save(save_diagram)
-        writer.endElement("canvas")
     else:
         save_value(name, value)
 
@@ -174,7 +168,7 @@ def load_elements_generator(elements, factory, modeling_language, gaphor_version
     )
     yield from _load_attributes_and_references(elements, update_status_queue)
 
-    ensure_style_sheet_is_present(factory)
+    upgrade_ensure_style_sheet_is_present(factory)
 
     for id, elem in list(elements.items()):
         yield from update_status_queue()
@@ -184,48 +178,41 @@ def load_elements_generator(elements, factory, modeling_language, gaphor_version
 def _load_elements_and_canvasitems(
     elements, factory, modeling_language, gaphor_version, update_status_queue
 ):
-    def create_canvasitems(diagram, canvasitems, parent=None):
-        """Diagram is a Core Diagram, items is a list of
-        parser.canvasitem's."""
-        if version_lower_than(gaphor_version, (1, 1, 0)):
-            new_canvasitems = upgrade_message_item_to_1_1_0(canvasitems)
-            canvasitems.extend(new_canvasitems)
-            for item in new_canvasitems:
-                elements[item.id] = item
+    def create_element(elem):
+        if elem.element:
+            return
+        if version_lower_than(gaphor_version, (2, 1, 0)):
+            elem = upgrade_element_owned_comment_to_comment(elem)
+        if version_lower_than(gaphor_version, (2, 3, 0)):
+            elem = upgrade_package_owned_classifier_to_owned_type(elem)
+            elem = upgrade_implementation_to_interface_realization(elem)
+            elem = upgrade_feature_parameters_to_owned_parameter(elem)
+            elem = upgrade_parameter_owner_formal_param(elem)
+        if version_lower_than(gaphor_version, (2, 5, 0)):
+            elem = upgrade_diagram_element(elem)
+        if version_lower_than(gaphor_version, (2, 6, 0)):
+            elem = upgrade_generalization_arrow_direction(elem)
 
-        for item in canvasitems:
-            item = upgrade_canvas_item_to_1_0_2(item)
-            item = upgrade_canvas_item_to_1_3_0(item)
-            if version_lower_than(gaphor_version, (1, 1, 0)):
-                item = upgrade_presentation_item_to_1_1_0(item)
-            cls = modeling_language.lookup_diagram_item(item.type)
-            assert cls, f"No diagram item for type {item.type}"
-            item.element = diagram.create_as(cls, item.id, parent=parent)
-            create_canvasitems(diagram, item.canvasitems, parent=item.element)
+        cls = modeling_language.lookup_element(elem.type)
+        assert cls, f"Type {elem.type} can not be loaded: no such element"
+        if issubclass(cls, Presentation):
+            diagram_id = elem.references["diagram"]
+            diagram_elem = elements[diagram_id]
+            create_element(diagram_elem)
+            elem.element = factory.create_as(cls, elem.id, diagram_elem.element)
+        else:
+            elem.element = factory.create_as(cls, elem.id)
 
     for id, elem in list(elements.items()):
         yield from update_status_queue()
-        if isinstance(elem, parser.element):
-            if version_lower_than(gaphor_version, (2, 1, 0)):
-                elem = upgrade_element_to_2_1_0(elem)
-
-            cls = modeling_language.lookup_element(elem.type)
-            assert cls, f"Type {elem.type} can not be loaded: no such element"
-            elem.element = factory.create_as(cls, id)
-            if isinstance(elem.element, Diagram):
-                assert elem.canvas
-                create_canvasitems(elem.element, elem.canvas.canvasitems)
-        elif not isinstance(elem, parser.canvasitem):
-            raise ValueError(
-                f"Item with id {id} and type {type(elem)} can not be instantiated"
-            )
+        create_element(elem)
 
 
 def _load_attributes_and_references(elements, update_status_queue):
     for id, elem in list(elements.items()):
         yield from update_status_queue()
         # Ensure that all elements have their element instance ready...
-        assert hasattr(elem, "element")
+        assert elem.element
 
         # load attributes and references:
         for name, value in list(elem.values.items()):
@@ -322,95 +309,88 @@ def version_lower_than(gaphor_version, version):
     return tuple(map(int, parts[:2])) < version[:2]
 
 
-def upgrade_canvas_item_to_1_0_2(item):
-    if item.type == "MetaclassItem":
-        item.type = "ClassItem"
-    elif item.type == "SubsystemItem":
-        item.type = "ComponentItem"
-    return item
-
-
-def upgrade_presentation_item_to_1_1_0(item):
-    if "show_stereotypes_attrs" in item.values:
-        if item.type in (
-            "ClassItem",
-            "InterfaceItem",
-            "ArtifactItem",
-            "ComponentItem",
-            "NodeItem",
-        ):
-            item.values["show_stereotypes"] = item.values["show_stereotypes_attrs"]
-        del item.values["show_stereotypes_attrs"]
-
-    if "drawing-style" in item.values:
-        if item.type == "InterfaceItem":
-            item.values["folded"] = "1" if item.values["drawing-style"] == "3" else "0"
-        del item.values["drawing-style"]
-
-    if "show-attributes" in item.values and item.type in ("ClassItem", "InterfaceItem"):
-        item.values["show_attributes"] = item.values["show-attributes"]
-        del item.values["show-attributes"]
-
-    if "show-operations" in item.values and item.type in ("ClassItem", "InterfaceItem"):
-        item.values["show_operations"] = item.values["show-operations"]
-        del item.values["show-operations"]
-
-    return item
-
-
-def clone_canvasitem(item, subject_id):
-    assert not item.canvasitems, "Can not clone a canvas item with children"
-    assert isinstance(item.references["subject"], str)
-    new_item = parser.canvasitem(str(uuid.uuid1()), item.type)
-    new_item.values = dict(item.values)
-    new_item.references = dict(item.references)
-    new_item.references["subject"] = subject_id
-    return new_item
-
-
-def ensure_style_sheet_is_present(factory):
+# since 2.2.0
+def upgrade_ensure_style_sheet_is_present(factory):
     style_sheet = next(factory.select(StyleSheet), None)
     if not style_sheet:
         factory.create(StyleSheet)
 
 
-def upgrade_message_item_to_1_1_0(canvasitems):
-    """Create new MessageItem's for each `message` and `inverted` message."""
-    new_canvasitems = []
-    for item in canvasitems:
-        if item.type == "MessageItem" and item.references.get("subject"):
-            messages = item.references.get("message", [])
-            inverted = item.references.get("inverted", [])
-            if messages:
-                del item.references["message"]
-            if inverted:
-                del item.references["inverted"]
-            for m_id in messages:
-                new_item = clone_canvasitem(item, m_id)
-                new_canvasitems.append(new_item)
-            for m_id in inverted:
-                new_item = clone_canvasitem(item, m_id)
-                new_canvasitems.append(new_item)
-                # todo: invert handles, points will follow on connect
-                (
-                    new_item.references["head-connection"],
-                    new_item.references["tail-connection"],
-                ) = (
-                    new_item.references["tail-connection"],
-                    new_item.references["head-connection"],
-                )
-    return new_canvasitems
-
-
-def upgrade_canvas_item_to_1_3_0(item):
-    if item.type in ("InitialPseudostateItem", "HistoryPseudostateItem"):
-        item.type = "PseudostateItem"
-    return item
-
-
-def upgrade_element_to_2_1_0(elem):
+# since 2.1.0
+def upgrade_element_owned_comment_to_comment(elem):
     for name, refids in dict(elem.references).items():
         if name == "ownedComment":
             elem.references["comment"] = refids
             del elem.references["ownedComment"]
+            break
+    return elem
+
+
+# since 2.3.0
+def upgrade_package_owned_classifier_to_owned_type(elem):
+    for name, refids in dict(elem.references).items():
+        if name == "ownedClassifier":
+            elem.references["ownedType"] = refids
+            del elem.references["ownedClassifier"]
+            break
+    return elem
+
+
+# since 2.3.0
+def upgrade_implementation_to_interface_realization(elem):
+    if elem.type == "Implementation":
+        elem.type = "InterfaceRealization"
+    return elem
+
+
+# since 2.3.0
+def upgrade_feature_parameters_to_owned_parameter(elem):
+    formal_params = []
+    return_results = []
+    for name, refids in dict(elem.references).items():
+        if name == "formalParameter":
+            formal_params = refids
+            del elem.references["formalParameter"]
+        elif name == "returnResult":
+            return_results = refids
+            del elem.references["returnResult"]
+    elem.references["ownedParameter"] = formal_params + return_results
+    return elem
+
+
+# since 2.3.0
+def upgrade_parameter_owner_formal_param(elem):
+    for name, refids in dict(elem.references).items():
+        if name == "ownerReturnParam":
+            elem.references["ownerFormalParam"] = refids
+            del elem.references["ownerReturnParam"]
+            break
+    return elem
+
+
+# since 2.5.0
+def upgrade_diagram_element(elem):
+    if elem.type == "Diagram":
+        for name, refids in dict(elem.references).items():
+            if name == "package":
+                elem.references["element"] = refids
+                del elem.references["package"]
+                break
+    return elem
+
+
+# since 2.6.0
+def upgrade_generalization_arrow_direction(elem):
+    if elem.type == "GeneralizationItem":
+        head_ids, tail_ids = 0, 0
+        for name, refids in dict(elem.references).items():
+            if name == "head-connection":
+                head_ids = refids
+            elif name == "tail-connection":
+                tail_ids = refids
+        if head_ids and tail_ids:
+            elem.references["head-connection"], elem.references["tail-connection"] = (
+                tail_ids,
+                head_ids,
+            )
     return elem
