@@ -16,11 +16,11 @@ from gaphor.core.modeling import StyleSheet
 from gaphor.core.modeling.diagram import StyledDiagram
 from gaphor.core.modeling.event import AttributeUpdated, ElementDeleted
 from gaphor.diagram.diagramtoolbox import tooliter
-from gaphor.diagram.diagramtools import apply_default_tool_set, apply_placement_tool_set
-from gaphor.diagram.diagramtools.placement import create_item
 from gaphor.diagram.painter import ItemPainter
 from gaphor.diagram.selection import Selection
 from gaphor.diagram.support import get_diagram_item
+from gaphor.diagram.tools import apply_default_tool_set, apply_placement_tool_set
+from gaphor.diagram.tools.placement import create_item, open_editor
 from gaphor.transaction import Transaction
 from gaphor.ui.event import DiagramSelectionChanged, Notification, ToolSelected
 
@@ -146,8 +146,8 @@ class DiagramPage:
                 Gdk.DragAction.MOVE | Gdk.DragAction.COPY | Gdk.DragAction.LINK,
             )
         else:
-            # TODO: Gtk4 - use controllers DragSource and DropTarget
-            pass
+            # TODO: GTK4 - use controllers DragSource and DropTarget
+            ...
 
         self.diagram_css = Gtk.CssProvider.new()
         view.get_style_context().add_provider(
@@ -251,22 +251,20 @@ class DiagramPage:
         self.view = None
 
     def select_tool(self, tool_name: str):
-        if self.view:
-            self.apply_tool_set(tool_name)
-            icon_name = self.get_tool_icon_name(tool_name)
-            if Gtk.get_major_version() == 3:
-                window = self.view.get_window()
-                if icon_name and window:
-                    window.set_cursor(
-                        get_placement_cursor(window.get_display(), icon_name)
-                    )
-                elif window:
-                    window.set_cursor(None)
-            else:
-                if icon_name:
-                    self.view.set_cursor(get_placement_cursor(None, icon_name))
-                else:
-                    self.view.set_cursor(None)
+        if not self.view:
+            return
+        self.apply_tool_set(tool_name)
+        icon_name = self.get_tool_icon_name(tool_name)
+        if Gtk.get_major_version() == 3:
+            window = self.view.get_window()
+            if icon_name and window:
+                window.set_cursor(get_placement_cursor(window.get_display(), icon_name))
+            elif window:
+                window.set_cursor(None)
+        elif icon_name:
+            self.view.set_cursor(get_placement_cursor(None, icon_name))
+        else:
+            self.view.set_cursor(None)
 
     def set_drawing_style(self):
         """Set the drawing style for the diagram based on the active style
@@ -277,10 +275,11 @@ class DiagramPage:
         style = self.diagram.style(StyledDiagram(self.diagram, self.view))
 
         bg = style.get("background-color")
+        # Default background to white, slightly gray in dark mode
+        if not bg or bg[3] == 0.0:
+            bg = (1.0, 1.0, 1.0, 0.94)
         self.diagram_css.load_from_data(
             f"diagramview {{ background-color: rgba({int(255*bg[0])}, {int(255*bg[1])}, {int(255*bg[2])}, {bg[3]}); }}".encode()
-            if bg
-            else b""
         )
 
         view = self.view
@@ -322,7 +321,8 @@ class DiagramPage:
         ):
             tool_def = self.get_tool_def(data.get_data().decode())
             with Transaction(self.event_manager):
-                create_item(view, tool_def.item_factory, x, y)
+                item = create_item(view, tool_def.item_factory, x, y)
+            open_editor(item, view, self.event_manager)
             context.finish(True, False, time)
         elif (
             data
