@@ -3,7 +3,7 @@
 import logging
 from typing import Optional
 
-from gi.repository import GLib, Gtk
+from gi.repository import GLib, Gtk, GtkSource
 
 from gaphor.abc import ActionProvider
 from gaphor.core import Transaction, action, event_handler
@@ -247,6 +247,7 @@ class SettingsStack:
     def __init__(self, event_manager, element_factory):
         self.event_manager = event_manager
         self.element_factory = element_factory
+        self.lang_manager = GtkSource.LanguageManager.get_default()
 
         def tx_update_style_sheet(style_sheet, text):
             self._in_update = 1
@@ -259,6 +260,7 @@ class SettingsStack:
 
     def open(self, builder):
         self.style_sheet_buffer = builder.get_object("style-sheet-buffer")
+        self.style_sheet_buffer.set_language(self.lang_manager.get_language("css"))
         self.style_sheet_view = builder.get_object("style-sheet-view")
 
         self.event_manager.subscribe(self._model_ready)
