@@ -17,6 +17,7 @@ from gaphor.event import (
     SessionCreated,
     SessionShutdownRequested,
 )
+from gaphor.i18n import translated_ui_string
 from gaphor.services.modelinglanguage import ModelingLanguageChanged
 from gaphor.services.undomanager import UndoManagerStateChanged
 from gaphor.ui.abc import UIComponent
@@ -31,10 +32,8 @@ log = logging.getLogger(__name__)
 
 def new_builder():
     builder = Gtk.Builder()
-    builder.set_translation_domain("gaphor")
     ui_file = "mainwindow.glade" if Gtk.get_major_version() == 3 else "mainwindow.ui"
-    with importlib.resources.path("gaphor.ui", ui_file) as glade_file:
-        builder.add_from_file(str(glade_file))
+    builder.add_from_string(translated_ui_string("gaphor.ui", ui_file))
     return builder
 
 
@@ -56,8 +55,8 @@ def create_hamburger_model(export_menu, tools_menu):
     model.append_section(None, part)
 
     part = Gio.Menu.new()
-    part.append(gettext("Keyboard Shortcuts"), "app.shortcuts")
-    part.append(gettext("About Gaphor"), "app.about")
+    part.append(gettext("Keyboard Shortcuts"), "win.shortcuts")
+    part.append(gettext("About Gaphor"), "win.about")
     model.append_section(None, part)
 
     return model
@@ -295,7 +294,7 @@ class MainWindow(Service, ActionProvider):
             a.set_enabled(event.enabled)
         else:
             # TODO: GTK4 - enable an action (shortcut?)
-            pass
+            ...
 
     @event_handler(ModelingLanguageChanged)
     def _on_modeling_language_selection_changed(self, event=None):
