@@ -206,15 +206,25 @@ class Namespace(UIComponent, ActionProvider):
                 isinstance(element, UML.Package)
             )
             action_group.lookup_action("delete").set_enabled(
-                isinstance(element, Diagram)
-                or (isinstance(element, UML.Package) and not element.presentation)
+                isinstance(
+                    element,
+                    (
+                        Diagram,
+                        UML.Package,
+                        UML.Interaction,
+                        UML.StateMachine,
+                        UML.Region,
+                        UML.Activity,
+                    ),
+                )
+                and not element.presentation
             )
             action_group.lookup_action("rename").set_enabled(
-                isinstance(element, UML.NamedElement)
+                isinstance(element, (Diagram, UML.NamedElement))
             )
         else:
             # TODO: GTK4 - enable/disable actions based on view state
-            pass
+            ...
 
     def _on_view_destroyed(self, widget):
         self.close()
@@ -264,7 +274,7 @@ class Namespace(UIComponent, ActionProvider):
             log.debug(f"No action defined for element {type(element).__name__}")
 
     @action(name="tree-view.show-in-diagram")
-    def tree_view_show_in_diagram(self, diagram_id: str):
+    def tree_view_show_in_diagram(self, diagram_id: str) -> None:
         element = self.element_factory.lookup(diagram_id)
         self.event_manager.handle(DiagramOpened(element))
 
@@ -291,9 +301,9 @@ class Namespace(UIComponent, ActionProvider):
         diagram = self.element_factory.create(Diagram)
         if isinstance(element, UML.NamedElement):
             diagram.element = element
-            diagram.name = f"{element.name} diagram"
+            diagram.name = gettext("{name} diagram").format(name=element.name)
         else:
-            diagram.name = "New diagram"
+            diagram.name = gettext("New diagram")
         self.select_element(diagram)
         self.event_manager.handle(DiagramOpened(diagram))
         self.tree_view_rename_selected()
@@ -306,7 +316,11 @@ class Namespace(UIComponent, ActionProvider):
         package = self.element_factory.create(UML.Package)
         package.package = element
 
-        package.name = f"{element.name} package" if element else "New model"
+        package.name = (
+            gettext("{name} package").format(name=element.name)
+            if element
+            else gettext("New model")
+        )
         self.select_element(package)
         self.tree_view_rename_selected()
 
@@ -314,17 +328,17 @@ class Namespace(UIComponent, ActionProvider):
     @transactional
     def tree_view_delete(self):
         element = self.get_selected_element()
-        if isinstance(element, UML.Package):
-            element.unlink()
-        elif isinstance(element, Diagram):
+        if isinstance(element, Diagram):
             m = Gtk.MessageDialog(
                 None,
                 Gtk.DialogFlags.MODAL,
                 Gtk.MessageType.QUESTION,
                 Gtk.ButtonsType.YES_NO,
-                "Do you really want to delete diagram %s?\n\n"
-                "This will possibly delete diagram items\n"
-                "that are not shown in other diagrams." % (element.name or "<None>"),
+                gettext(
+                    "Do you really want to delete diagram {name}?\n\n"
+                    "This will possibly delete diagram items\n"
+                    "that are not shown in other diagrams."
+                ).format(name=element.name or gettext("<None>")),
             )
             if m.run() == Gtk.ResponseType.YES:
                 for i in reversed(list(element.get_all_items())):
@@ -334,3 +348,5 @@ class Namespace(UIComponent, ActionProvider):
                     i.unlink()
                 element.unlink()
             m.destroy()
+        elif element:
+            element.unlink()
